Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(29)

Unified Diff: util/mach/symbolic_constants_mach_test.cc

Issue 656703002: Convert NULL to nullptr (Closed) Base URL: https://chromium.googlesource.com/crashpad/crashpad@master
Patch Set: Fix 80-column violations Created 6 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « util/mach/symbolic_constants_mach.cc ('k') | util/mach/task_memory.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: util/mach/symbolic_constants_mach_test.cc
diff --git a/util/mach/symbolic_constants_mach_test.cc b/util/mach/symbolic_constants_mach_test.cc
index 0410f2e37333af342a0148eab19884d70fcfd25c..ff7d71dbcb97f8a43c36583e5008513a5ef525b4 100644
--- a/util/mach/symbolic_constants_mach_test.cc
+++ b/util/mach/symbolic_constants_mach_test.cc
@@ -41,7 +41,7 @@ const StringToSymbolicConstantOptions kNormalOptions[] = {
kAllowFullName | kAllowShortName | kAllowNumber,
};
// If |expect| is NULL, the conversion is expected to fail. If |expect| is
// empty, the conversion is expected to succeed, but the precise returned string
// value is unknown. Otherwise, the conversion is expected to succeed, and
// |expect| contains the precise expected string value to be returned. If
@@ -171,7 +171,7 @@ TEST(SymbolicConstantsMach, ExceptionToString) {
if (exception > 0 && exception < EXC_TYPES_COUNT) {
TestExceptionToString(exception, "", "");
} else {
- TestExceptionToString(exception, NULL, NULL);
+ TestExceptionToString(exception, nullptr, nullptr);
}
}
}
@@ -591,8 +591,8 @@ TEST(SymbolicConstantsMach, ExceptionBehaviorToString) {
TestExceptionBehaviorToString(behavior, "", "");
TestExceptionBehaviorToString(behavior_mach, "", "");
} else {
- TestExceptionBehaviorToString(behavior, NULL, NULL);
- TestExceptionBehaviorToString(behavior_mach, NULL, NULL);
+ TestExceptionBehaviorToString(behavior, nullptr, nullptr);
+ TestExceptionBehaviorToString(behavior_mach, nullptr, nullptr);
}
}
}
@@ -867,7 +867,7 @@ TEST(SymbolicConstantsMach, ThreadStateFlavorToString) {
flavor == THREAD_STATE_FLAVOR_LIST_10_9) {
TestThreadStateFlavorToString(flavor, "", "");
} else {
- TestThreadStateFlavorToString(flavor, NULL, NULL);
+ TestThreadStateFlavorToString(flavor, nullptr, nullptr);
}
}
}
@@ -41,7 +41,7 @@ const StringToSymbolicConstantOptions kNormalOptions[] = {
kAllowFullName | kAllowShortName | kAllowNumber,
};
-// If |expect| is NULL, the conversion is expected to fail. If |expect| is
+// If |expect| is nullptr, the conversion is expected to fail. If |expect| is
// empty, the conversion is expected to succeed, but the precise returned string
// value is unknown. Otherwise, the conversion is expected to succeed, and
« no previous file with comments | « util/mach/symbolic_constants_mach.cc ('k') | util/mach/task_memory.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698